"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel, UnrecognizedStr
from openrouter.utils import validate_open_enum
from pydantic.functional_validators import PlainValidator
from typing import Literal, Union
from typing_extensions import Annotated, TypedDict


CodeEnum = Union[
    Literal[
        "server_error",
        "rate_limit_exceeded",
        "invalid_prompt",
        "vector_store_timeout",
        "invalid_image",
        "invalid_image_format",
        "invalid_base64_image",
        "invalid_image_url",
        "image_too_large",
        "image_too_small",
        "image_parse_error",
        "image_content_policy_violation",
        "invalid_image_mode",
        "image_file_too_large",
        "unsupported_image_media_type",
        "empty_image_file",
        "failed_to_download_image",
        "image_file_not_found",
    ],
    UnrecognizedStr,
]


class ResponsesErrorFieldTypedDict(TypedDict):
    r"""Error information returned from the API"""

    code: CodeEnum
    message: str


class ResponsesErrorField(BaseModel):
    r"""Error information returned from the API"""

    code: Annotated[CodeEnum, PlainValidator(validate_open_enum(False))]

    message: str
