"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


InstructType = Union[
    Literal[
        "none",
        "airoboros",
        "alpaca",
        "alpaca-modif",
        "chatml",
        "claude",
        "code-llama",
        "gemma",
        "llama2",
        "llama3",
        "mistral",
        "nemotron",
        "neural",
        "openchat",
        "phi3",
        "rwkv",
        "vicuna",
        "zephyr",
        "deepseek-r1",
        "deepseek-v3.1",
        "qwq",
        "qwen3",
    ],
    UnrecognizedStr,
]
r"""Instruction format type"""
