"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing_extensions import TypedDict


class ModelsCountResponseDataTypedDict(TypedDict):
    r"""Model count data"""

    count: float
    r"""Total number of available models"""


class ModelsCountResponseData(BaseModel):
    r"""Model count data"""

    count: float
    r"""Total number of available models"""


class ModelsCountResponseTypedDict(TypedDict):
    r"""Model count data"""

    data: ModelsCountResponseDataTypedDict
    r"""Model count data"""


class ModelsCountResponse(BaseModel):
    r"""Model count data"""

    data: ModelsCountResponseData
    r"""Model count data"""
