"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .openresponsestoplogprobs import (
    OpenResponsesTopLogprobs,
    OpenResponsesTopLogprobsTypedDict,
)
from openrouter.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class OpenResponsesLogProbsTypedDict(TypedDict):
    r"""Log probability information for a token"""

    logprob: float
    token: str
    top_logprobs: NotRequired[List[OpenResponsesTopLogprobsTypedDict]]


class OpenResponsesLogProbs(BaseModel):
    r"""Log probability information for a token"""

    logprob: float

    token: str

    top_logprobs: Optional[List[OpenResponsesTopLogprobs]] = None
