"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.components import (
    listendpointsresponse as components_listendpointsresponse,
)
from openrouter.types import BaseModel
from openrouter.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class ListEndpointsRequestTypedDict(TypedDict):
    author: str
    slug: str


class ListEndpointsRequest(BaseModel):
    author: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    slug: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class ListEndpointsResponseTypedDict(TypedDict):
    r"""Returns a list of endpoints"""

    data: components_listendpointsresponse.ListEndpointsResponseTypedDict
    r"""List of available endpoints for a model"""


class ListEndpointsResponse(BaseModel):
    r"""Returns a list of endpoints"""

    data: components_listendpointsresponse.ListEndpointsResponse
    r"""List of available endpoints for a model"""
