"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from openrouter.utils import FieldMetadata, PathParamMetadata, validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class DeleteKeysRequestTypedDict(TypedDict):
    hash: str
    r"""The hash identifier of the API key to delete"""


class DeleteKeysRequest(BaseModel):
    hash: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The hash identifier of the API key to delete"""


class DeleteKeysResponseTypedDict(TypedDict):
    r"""API key deleted successfully"""

    deleted: Literal[True]
    r"""Confirmation that the API key was deleted"""


class DeleteKeysResponse(BaseModel):
    r"""API key deleted successfully"""

    DELETED: Annotated[
        Annotated[Literal[True], AfterValidator(validate_const(True))],
        pydantic.Field(alias="deleted"),
    ] = True
    r"""Confirmation that the API key was deleted"""
