"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pdfparserengine import PDFParserEngine
from openrouter.types import BaseModel
from openrouter.utils import validate_open_enum
from pydantic.functional_validators import PlainValidator
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PDFParserOptionsTypedDict(TypedDict):
    r"""Options for PDF parsing."""

    engine: NotRequired[PDFParserEngine]
    r"""The engine to use for parsing PDF files."""


class PDFParserOptions(BaseModel):
    r"""Options for PDF parsing."""

    engine: Annotated[
        Optional[PDFParserEngine], PlainValidator(validate_open_enum(False))
    ] = None
    r"""The engine to use for parsing PDF files."""
