"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .responseinputaudio import ResponseInputAudio, ResponseInputAudioTypedDict
from .responseinputfile import ResponseInputFile, ResponseInputFileTypedDict
from .responseinputtext import ResponseInputText, ResponseInputTextTypedDict
from .responseinputvideo import ResponseInputVideo, ResponseInputVideoTypedDict
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from openrouter.utils import get_discriminator, validate_open_enum
from pydantic import Discriminator, Tag, model_serializer
from pydantic.functional_validators import PlainValidator
from typing import List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


OpenResponsesEasyInputMessageTypeMessage = Literal["message",]


OpenResponsesEasyInputMessageRoleDeveloper = Literal["developer",]


OpenResponsesEasyInputMessageRoleAssistant = Literal["assistant",]


OpenResponsesEasyInputMessageRoleSystem = Literal["system",]


OpenResponsesEasyInputMessageRoleUser = Literal["user",]


OpenResponsesEasyInputMessageRoleUnionTypedDict = TypeAliasType(
    "OpenResponsesEasyInputMessageRoleUnionTypedDict",
    Union[
        OpenResponsesEasyInputMessageRoleUser,
        OpenResponsesEasyInputMessageRoleSystem,
        OpenResponsesEasyInputMessageRoleAssistant,
        OpenResponsesEasyInputMessageRoleDeveloper,
    ],
)


OpenResponsesEasyInputMessageRoleUnion = TypeAliasType(
    "OpenResponsesEasyInputMessageRoleUnion",
    Union[
        OpenResponsesEasyInputMessageRoleUser,
        OpenResponsesEasyInputMessageRoleSystem,
        OpenResponsesEasyInputMessageRoleAssistant,
        OpenResponsesEasyInputMessageRoleDeveloper,
    ],
)


OpenResponsesEasyInputMessageContentType = Literal["input_image",]


OpenResponsesEasyInputMessageDetail = Union[
    Literal[
        "auto",
        "high",
        "low",
    ],
    UnrecognizedStr,
]


class OpenResponsesEasyInputMessageContentInputImageTypedDict(TypedDict):
    r"""Image input content item"""

    type: OpenResponsesEasyInputMessageContentType
    detail: OpenResponsesEasyInputMessageDetail
    image_url: NotRequired[Nullable[str]]


class OpenResponsesEasyInputMessageContentInputImage(BaseModel):
    r"""Image input content item"""

    type: OpenResponsesEasyInputMessageContentType

    detail: Annotated[
        OpenResponsesEasyInputMessageDetail, PlainValidator(validate_open_enum(False))
    ]

    image_url: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["image_url"]
        nullable_fields = ["image_url"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


OpenResponsesEasyInputMessageContentUnion1TypedDict = TypeAliasType(
    "OpenResponsesEasyInputMessageContentUnion1TypedDict",
    Union[
        ResponseInputTextTypedDict,
        ResponseInputAudioTypedDict,
        ResponseInputVideoTypedDict,
        OpenResponsesEasyInputMessageContentInputImageTypedDict,
        ResponseInputFileTypedDict,
    ],
)


OpenResponsesEasyInputMessageContentUnion1 = Annotated[
    Union[
        Annotated[ResponseInputText, Tag("input_text")],
        Annotated[OpenResponsesEasyInputMessageContentInputImage, Tag("input_image")],
        Annotated[ResponseInputFile, Tag("input_file")],
        Annotated[ResponseInputAudio, Tag("input_audio")],
        Annotated[ResponseInputVideo, Tag("input_video")],
    ],
    Discriminator(lambda m: get_discriminator(m, "type", "type")),
]


OpenResponsesEasyInputMessageContentUnion2TypedDict = TypeAliasType(
    "OpenResponsesEasyInputMessageContentUnion2TypedDict",
    Union[List[OpenResponsesEasyInputMessageContentUnion1TypedDict], str],
)


OpenResponsesEasyInputMessageContentUnion2 = TypeAliasType(
    "OpenResponsesEasyInputMessageContentUnion2",
    Union[List[OpenResponsesEasyInputMessageContentUnion1], str],
)


class OpenResponsesEasyInputMessageTypedDict(TypedDict):
    role: OpenResponsesEasyInputMessageRoleUnionTypedDict
    content: OpenResponsesEasyInputMessageContentUnion2TypedDict
    type: NotRequired[OpenResponsesEasyInputMessageTypeMessage]


class OpenResponsesEasyInputMessage(BaseModel):
    role: OpenResponsesEasyInputMessageRoleUnion

    content: OpenResponsesEasyInputMessageContentUnion2

    type: Optional[OpenResponsesEasyInputMessageTypeMessage] = None
