"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


OpenResponsesImageGenCallPartialImageType = Literal[
    "response.image_generation_call.partial_image",
]


class OpenResponsesImageGenCallPartialImageTypedDict(TypedDict):
    r"""Image generation call with partial image"""

    type: OpenResponsesImageGenCallPartialImageType
    item_id: str
    output_index: float
    sequence_number: float
    partial_image_b64: str
    partial_image_index: float


class OpenResponsesImageGenCallPartialImage(BaseModel):
    r"""Image generation call with partial image"""

    type: OpenResponsesImageGenCallPartialImageType

    item_id: str

    output_index: float

    sequence_number: float

    partial_image_b64: str

    partial_image_index: float
