"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatmessagecontentitemcachecontrol import (
    ChatMessageContentItemCacheControl,
    ChatMessageContentItemCacheControlTypedDict,
)
from openrouter.types import BaseModel
from openrouter.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ChatMessageContentItemTextTypedDict(TypedDict):
    text: str
    type: Literal["text"]
    cache_control: NotRequired[ChatMessageContentItemCacheControlTypedDict]


class ChatMessageContentItemText(BaseModel):
    text: str

    TYPE: Annotated[
        Annotated[Literal["text"], AfterValidator(validate_const("text"))],
        pydantic.Field(alias="type"),
    ] = "text"

    cache_control: Optional[ChatMessageContentItemCacheControl] = None
