"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from openrouter.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class NamedToolChoiceFunctionTypedDict(TypedDict):
    name: str


class NamedToolChoiceFunction(BaseModel):
    name: str


class NamedToolChoiceTypedDict(TypedDict):
    function: NamedToolChoiceFunctionTypedDict
    type: Literal["function"]


class NamedToolChoice(BaseModel):
    function: NamedToolChoiceFunction

    TYPE: Annotated[
        Annotated[Literal["function"], AfterValidator(validate_const("function"))],
        pydantic.Field(alias="type"),
    ] = "function"
