"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .websearchstatus import WebSearchStatus
from openrouter.types import BaseModel
from openrouter.utils import validate_open_enum
from pydantic.functional_validators import PlainValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


ResponsesWebSearchCallOutputType = Literal["web_search_call",]


class ResponsesWebSearchCallOutputTypedDict(TypedDict):
    type: ResponsesWebSearchCallOutputType
    id: str
    status: WebSearchStatus


class ResponsesWebSearchCallOutput(BaseModel):
    type: ResponsesWebSearchCallOutputType

    id: str

    status: Annotated[WebSearchStatus, PlainValidator(validate_open_enum(False))]
