"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ResponseInputVideoType = Literal["input_video",]


class ResponseInputVideoTypedDict(TypedDict):
    r"""Video input content item"""

    type: ResponseInputVideoType
    video_url: str
    r"""A base64 data URL or remote URL that resolves to a video file"""


class ResponseInputVideo(BaseModel):
    r"""Video input content item"""

    type: ResponseInputVideoType

    video_url: str
    r"""A base64 data URL or remote URL that resolves to a video file"""
