"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


ResponsesSearchContextSize = Union[
    Literal[
        "low",
        "medium",
        "high",
    ],
    UnrecognizedStr,
]
r"""Size of the search context for web search tools"""
