"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .imagegenerationstatus import ImageGenerationStatus
from openrouter.types import BaseModel, Nullable, OptionalNullable, UNSET_SENTINEL
from openrouter.utils import validate_open_enum
from pydantic import model_serializer
from pydantic.functional_validators import PlainValidator
from typing import Literal
from typing_extensions import Annotated, NotRequired, TypedDict


OutputItemImageGenerationCallType = Literal["image_generation_call",]


class OutputItemImageGenerationCallTypedDict(TypedDict):
    type: OutputItemImageGenerationCallType
    id: str
    status: ImageGenerationStatus
    result: NotRequired[Nullable[str]]


class OutputItemImageGenerationCall(BaseModel):
    type: OutputItemImageGenerationCallType

    id: str

    status: Annotated[ImageGenerationStatus, PlainValidator(validate_open_enum(False))]

    result: OptionalNullable[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["result"]
        nullable_fields = ["result"]
        null_default_fields = ["result"]

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
