"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ChatStreamOptionsTypedDict(TypedDict):
    include_usage: NotRequired[bool]


class ChatStreamOptions(BaseModel):
    include_usage: Optional[bool] = None
