"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.components import (
    chatresponse as components_chatresponse,
    chatstreamingresponsechunk as components_chatstreamingresponsechunk,
)
from openrouter.utils import eventstreaming
from typing import Union
from typing_extensions import TypeAliasType


SendChatCompletionRequestResponseTypedDict = TypeAliasType(
    "SendChatCompletionRequestResponseTypedDict",
    Union[
        components_chatresponse.ChatResponseTypedDict,
        Union[
            eventstreaming.EventStream[
                components_chatstreamingresponsechunk.ChatStreamingResponseChunkDataTypedDict
            ],
            eventstreaming.EventStreamAsync[
                components_chatstreamingresponsechunk.ChatStreamingResponseChunkDataTypedDict
            ],
        ],
    ],
)


SendChatCompletionRequestResponse = TypeAliasType(
    "SendChatCompletionRequestResponse",
    Union[
        components_chatresponse.ChatResponse,
        Union[
            eventstreaming.EventStream[
                components_chatstreamingresponsechunk.ChatStreamingResponseChunkData
            ],
            eventstreaming.EventStreamAsync[
                components_chatstreamingresponsechunk.ChatStreamingResponseChunkData
            ],
        ],
    ],
)
