"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


OpenResponsesReasoningDeltaEventType = Literal["response.reasoning_text.delta",]


class OpenResponsesReasoningDeltaEventTypedDict(TypedDict):
    r"""Event emitted when reasoning text delta is streamed"""

    type: OpenResponsesReasoningDeltaEventType
    output_index: float
    item_id: str
    content_index: float
    delta: str
    sequence_number: float


class OpenResponsesReasoningDeltaEvent(BaseModel):
    r"""Event emitted when reasoning text delta is streamed"""

    type: OpenResponsesReasoningDeltaEventType

    output_index: float

    item_id: str

    content_index: float

    delta: str

    sequence_number: float
