"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing_extensions import TypedDict


class PerRequestLimitsTypedDict(TypedDict):
    r"""Per-request token limits"""

    prompt_tokens: float
    r"""Maximum prompt tokens per request"""
    completion_tokens: float
    r"""Maximum completion tokens per request"""


class PerRequestLimits(BaseModel):
    r"""Per-request token limits"""

    prompt_tokens: float
    r"""Maximum prompt tokens per request"""

    completion_tokens: float
    r"""Maximum completion tokens per request"""
