"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OpenResponsesTopLogprobsTypedDict(TypedDict):
    r"""Alternative token with its log probability"""

    token: NotRequired[str]
    logprob: NotRequired[float]


class OpenResponsesTopLogprobs(BaseModel):
    r"""Alternative token with its log probability"""

    token: Optional[str] = None

    logprob: Optional[float] = None
