"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


OpenResponsesReasoningSummaryTextDeltaEventType = Literal[
    "response.reasoning_summary_text.delta",
]


class OpenResponsesReasoningSummaryTextDeltaEventTypedDict(TypedDict):
    r"""Event emitted when reasoning summary text delta is streamed"""

    type: OpenResponsesReasoningSummaryTextDeltaEventType
    item_id: str
    output_index: float
    summary_index: float
    delta: str
    sequence_number: float


class OpenResponsesReasoningSummaryTextDeltaEvent(BaseModel):
    r"""Event emitted when reasoning summary text delta is streamed"""

    type: OpenResponsesReasoningSummaryTextDeltaEventType

    item_id: str

    output_index: float

    summary_index: float

    delta: str

    sequence_number: float
