"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ._schema3 import Schema3, Schema3TypedDict
from .chatstreamingmessagetoolcall import (
    ChatStreamingMessageToolCall,
    ChatStreamingMessageToolCallTypedDict,
)
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Literal, Optional
from typing_extensions import NotRequired, TypedDict


ChatStreamingMessageChunkRole = Literal["assistant",]


class ChatStreamingMessageChunkTypedDict(TypedDict):
    role: NotRequired[ChatStreamingMessageChunkRole]
    content: NotRequired[Nullable[str]]
    reasoning: NotRequired[Nullable[str]]
    refusal: NotRequired[Nullable[str]]
    tool_calls: NotRequired[List[ChatStreamingMessageToolCallTypedDict]]
    reasoning_details: NotRequired[List[Schema3TypedDict]]


class ChatStreamingMessageChunk(BaseModel):
    role: Optional[ChatStreamingMessageChunkRole] = None

    content: OptionalNullable[str] = UNSET

    reasoning: OptionalNullable[str] = UNSET

    refusal: OptionalNullable[str] = UNSET

    tool_calls: Optional[List[ChatStreamingMessageToolCall]] = None

    reasoning_details: Optional[List[Schema3]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "role",
            "content",
            "reasoning",
            "refusal",
            "tool_calls",
            "reasoning_details",
        ]
        nullable_fields = ["content", "reasoning", "refusal"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
