"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from openrouter.utils import get_discriminator, validate_const, validate_open_enum
import pydantic
from pydantic import Discriminator, Tag, model_serializer
from pydantic.functional_validators import AfterValidator, PlainValidator
from typing import Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


Schema5 = Union[
    Literal[
        "unknown",
        "openai-responses-v1",
        "azure-openai-responses-v1",
        "xai-responses-v1",
        "anthropic-claude-v1",
        "google-gemini-v1",
    ],
    UnrecognizedStr,
]


class Schema3ReasoningTextTypedDict(TypedDict):
    type: Literal["reasoning.text"]
    text: NotRequired[Nullable[str]]
    signature: NotRequired[Nullable[str]]
    id: NotRequired[Nullable[str]]
    format_: NotRequired[Nullable[Schema5]]
    index: NotRequired[float]


class Schema3ReasoningText(BaseModel):
    TYPE: Annotated[
        Annotated[
            Literal["reasoning.text"], AfterValidator(validate_const("reasoning.text"))
        ],
        pydantic.Field(alias="type"),
    ] = "reasoning.text"

    text: OptionalNullable[str] = UNSET

    signature: OptionalNullable[str] = UNSET

    id: OptionalNullable[str] = UNSET

    format_: Annotated[
        Annotated[OptionalNullable[Schema5], PlainValidator(validate_open_enum(False))],
        pydantic.Field(alias="format"),
    ] = UNSET

    index: Optional[float] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["text", "signature", "id", "format", "index"]
        nullable_fields = ["text", "signature", "id", "format"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class Schema3ReasoningEncryptedTypedDict(TypedDict):
    data: str
    type: Literal["reasoning.encrypted"]
    id: NotRequired[Nullable[str]]
    format_: NotRequired[Nullable[Schema5]]
    index: NotRequired[float]


class Schema3ReasoningEncrypted(BaseModel):
    data: str

    TYPE: Annotated[
        Annotated[
            Literal["reasoning.encrypted"],
            AfterValidator(validate_const("reasoning.encrypted")),
        ],
        pydantic.Field(alias="type"),
    ] = "reasoning.encrypted"

    id: OptionalNullable[str] = UNSET

    format_: Annotated[
        Annotated[OptionalNullable[Schema5], PlainValidator(validate_open_enum(False))],
        pydantic.Field(alias="format"),
    ] = UNSET

    index: Optional[float] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["id", "format", "index"]
        nullable_fields = ["id", "format"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class Schema3ReasoningSummaryTypedDict(TypedDict):
    summary: str
    type: Literal["reasoning.summary"]
    id: NotRequired[Nullable[str]]
    format_: NotRequired[Nullable[Schema5]]
    index: NotRequired[float]


class Schema3ReasoningSummary(BaseModel):
    summary: str

    TYPE: Annotated[
        Annotated[
            Literal["reasoning.summary"],
            AfterValidator(validate_const("reasoning.summary")),
        ],
        pydantic.Field(alias="type"),
    ] = "reasoning.summary"

    id: OptionalNullable[str] = UNSET

    format_: Annotated[
        Annotated[OptionalNullable[Schema5], PlainValidator(validate_open_enum(False))],
        pydantic.Field(alias="format"),
    ] = UNSET

    index: Optional[float] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["id", "format", "index"]
        nullable_fields = ["id", "format"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


Schema3TypedDict = TypeAliasType(
    "Schema3TypedDict",
    Union[
        Schema3ReasoningSummaryTypedDict,
        Schema3ReasoningEncryptedTypedDict,
        Schema3ReasoningTextTypedDict,
    ],
)


Schema3 = Annotated[
    Union[
        Annotated[Schema3ReasoningSummary, Tag("reasoning.summary")],
        Annotated[Schema3ReasoningEncrypted, Tag("reasoning.encrypted")],
        Annotated[Schema3ReasoningText, Tag("reasoning.text")],
    ],
    Discriminator(lambda m: get_discriminator(m, "type", "type")),
]
