"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing_extensions import TypedDict


class PercentileStatsTypedDict(TypedDict):
    r"""Latency percentiles in milliseconds over the last 30 minutes. Latency measures time to first token. Only visible when authenticated with an API key or cookie; returns null for unauthenticated requests."""

    p50: float
    r"""Median (50th percentile)"""
    p75: float
    r"""75th percentile"""
    p90: float
    r"""90th percentile"""
    p99: float
    r"""99th percentile"""


class PercentileStats(BaseModel):
    r"""Latency percentiles in milliseconds over the last 30 minutes. Latency measures time to first token. Only visible when authenticated with an API key or cookie; returns null for unauthenticated requests."""

    p50: float
    r"""Median (50th percentile)"""

    p75: float
    r"""75th percentile"""

    p90: float
    r"""90th percentile"""

    p99: float
    r"""99th percentile"""
