"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from openrouter.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class ChatMessageContentItemAudioInputAudioTypedDict(TypedDict):
    data: str
    format_: str


class ChatMessageContentItemAudioInputAudio(BaseModel):
    data: str

    format_: Annotated[str, pydantic.Field(alias="format")]


class ChatMessageContentItemAudioTypedDict(TypedDict):
    input_audio: ChatMessageContentItemAudioInputAudioTypedDict
    type: Literal["input_audio"]


class ChatMessageContentItemAudio(BaseModel):
    input_audio: ChatMessageContentItemAudioInputAudio

    TYPE: Annotated[
        Annotated[
            Literal["input_audio"], AfterValidator(validate_const("input_audio"))
        ],
        pydantic.Field(alias="type"),
    ] = "input_audio"
