"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


OpenAIResponsesRefusalContentType = Literal["refusal",]


class OpenAIResponsesRefusalContentTypedDict(TypedDict):
    type: OpenAIResponsesRefusalContentType
    refusal: str


class OpenAIResponsesRefusalContent(BaseModel):
    type: OpenAIResponsesRefusalContentType

    refusal: str
