"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


OpenResponsesImageGenCallCompletedType = Literal[
    "response.image_generation_call.completed",
]


class OpenResponsesImageGenCallCompletedTypedDict(TypedDict):
    r"""Image generation call completed"""

    type: OpenResponsesImageGenCallCompletedType
    item_id: str
    output_index: float
    sequence_number: float


class OpenResponsesImageGenCallCompleted(BaseModel):
    r"""Image generation call completed"""

    type: OpenResponsesImageGenCallCompletedType

    item_id: str

    output_index: float

    sequence_number: float
