"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


WebSearchEngine = Union[
    Literal[
        "native",
        "exa",
    ],
    UnrecognizedStr,
]
r"""The search engine to use for web search."""
