"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.components import activityitem as components_activityitem
from openrouter.types import BaseModel
from openrouter.utils import FieldMetadata, QueryParamMetadata
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetUserActivityRequestTypedDict(TypedDict):
    date_: NotRequired[str]
    r"""Filter by a single UTC date in the last 30 days (YYYY-MM-DD format)."""


class GetUserActivityRequest(BaseModel):
    date_: Annotated[
        Optional[str],
        pydantic.Field(alias="date"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Filter by a single UTC date in the last 30 days (YYYY-MM-DD format)."""


class GetUserActivityResponseTypedDict(TypedDict):
    r"""Returns user activity data grouped by endpoint"""

    data: List[components_activityitem.ActivityItemTypedDict]
    r"""List of activity items"""


class GetUserActivityResponse(BaseModel):
    r"""Returns user activity data grouped by endpoint"""

    data: List[components_activityitem.ActivityItem]
    r"""List of activity items"""
