"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .model import Model, ModelTypedDict
from openrouter.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ModelsListResponseTypedDict(TypedDict):
    r"""List of available models"""

    data: List[ModelTypedDict]
    r"""List of available models"""


class ModelsListResponse(BaseModel):
    r"""List of available models"""

    data: List[Model]
    r"""List of available models"""
